==> estateplat-common-1.2.4-20220606.055821-1031-sources.jar: cn/gtmap/estateplat/model/server/core/BdcLq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 不动产林权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_lq")
public class BdcLq extends QllxParent {
    /* @Id
  private String qlid;//权利Id
  private String bdcdyid;//不动产单元Id*/

    private Double syqmj;//使用权(承包)面积(亩)
    private Date ldsyksqx;//林地使用（承包）开始期限
    private Date ldsyjsqx;//林地使用（承包）结束期限
    private String zysz;//主要树种
    private Integer zs;//株数
    private String lz;//林种
    private String zlnd;//造林年度
    private String xdm;//小地名
    private String lb;//林班
    private String xb;//小班
    /* private String proid;//项目ID*/
    private String ywh;//业务号
    private String qllx;//权利类型
    private String gyqk;//共有情况
    private String dbr;//登簿人
    private Date djsj;//登记时间
    private String fj;//附记
    private String ldsyqxz;//林地所有权性质           \
    private String qy;//起源

    private String lmsyqr;//林木使用权人
    private String lmsuqr;//林木所有权人

    private String fbfmc;//发包方名称
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销

    private String fbfdm;//发包方代码
    private String sllb;//森林类别 “公益林”或“商品林”
    private String ldsyqxsfyj;//林地使用期限是否永久 （0：否 1：是）

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_lq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况

    /**
     * 事权等级
     */
    private String sqdj;

    public String getSqdj() {
        return sqdj;
    }

    public void setSqdj(String sqdj) {
        this.sqdj = sqdj;
    }

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getSllb() {
        return sllb;
    }

    public void setSllb(String sllb) {
        this.sllb = sllb;
    }

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getLmsyqr() {
        return lmsyqr;
    }

    public void setLmsyqr(String lmsyqr) {
        this.lmsyqr = lmsyqr;
    }

    public String getLmsuqr() {
        return lmsuqr;
    }

    public void setLmsuqr(String lmsuqr) {
        this.lmsuqr = lmsuqr;
    }


    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public String getLdsyqxz() {
        return ldsyqxz;
    }

    public void setLdsyqxz(String ldsyqxz) {
        this.ldsyqxz = ldsyqxz;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getLdsyksqx() {
        return ldsyksqx;
    }

    public void setLdsyksqx(Date ldsyksqx) {
        this.ldsyksqx = ldsyksqx;
    }

    public Date getLdsyjsqx() {
        return ldsyjsqx;
    }

    public void setLdsyjsqx(Date ldsyjsqx) {
        this.ldsyjsqx = ldsyjsqx;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getZlnd() {
        return zlnd;
    }

    public void setZlnd(String zlnd) {
        this.zlnd = zlnd;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }


    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getLdsyqxsfyj() {
        return ldsyqxsfyj;
    }

    public void setLdsyqxsfyj(String ldsyqxsfyj) {
        this.ldsyqxsfyj = ldsyqxsfyj;
    }
}

==> estateplat-common-1.2.4-20250306.090639-1296-sources.jar: cn/gtmap/estateplat/model/server/core/BdcLq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 不动产林权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_lq")
public class BdcLq extends QllxParent {
    /* @Id
  private String qlid;//权利Id
  private String bdcdyid;//不动产单元Id*/

    private Double syqmj;//使用权(承包)面积(亩)
    private Date ldsyksqx;//林地使用（承包）开始期限
    private Date ldsyjsqx;//林地使用（承包）结束期限
    private String zysz;//主要树种
    private Integer zs;//株数
    private String lz;//林种
    private String zlnd;//造林年度
    private String xdm;//小地名
    private String lb;//林班
    private String xb;//小班
    /* private String proid;//项目ID*/
    private String ywh;//业务号
    private String qllx;//权利类型
    private String gyqk;//共有情况
    private String dbr;//登簿人
    private Date djsj;//登记时间
    private String fj;//附记
    private String ldsyqxz;//林地所有权性质           \
    private String qy;//起源

    private String lmsyqr;//林木使用权人
    private String lmsuqr;//林木所有权人

    private String fbfmc;//发包方名称
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销

    private String fbfdm;//发包方代码
    private String sllb;//森林类别 “公益林”或“商品林”
    private String ldsyqxsfyj;//林地使用期限是否永久 （0：否 1：是）

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_lq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况

    /**
     * 事权等级
     */
    private String sqdj;

    private String htbh;// 合同编号

    private String fbfsfzjh;// 发包方身份证件号

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getFbfsfzjh() {
        return fbfsfzjh;
    }

    public void setFbfsfzjh(String fbfsfzjh) {
        this.fbfsfzjh = fbfsfzjh;
    }

    public String getSqdj() {
        return sqdj;
    }

    public void setSqdj(String sqdj) {
        this.sqdj = sqdj;
    }

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getSllb() {
        return sllb;
    }

    public void setSllb(String sllb) {
        this.sllb = sllb;
    }

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getLmsyqr() {
        return lmsyqr;
    }

    public void setLmsyqr(String lmsyqr) {
        this.lmsyqr = lmsyqr;
    }

    public String getLmsuqr() {
        return lmsuqr;
    }

    public void setLmsuqr(String lmsuqr) {
        this.lmsuqr = lmsuqr;
    }


    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public String getLdsyqxz() {
        return ldsyqxz;
    }

    public void setLdsyqxz(String ldsyqxz) {
        this.ldsyqxz = ldsyqxz;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getLdsyksqx() {
        return ldsyksqx;
    }

    public void setLdsyksqx(Date ldsyksqx) {
        this.ldsyksqx = ldsyksqx;
    }

    public Date getLdsyjsqx() {
        return ldsyjsqx;
    }

    public void setLdsyjsqx(Date ldsyjsqx) {
        this.ldsyjsqx = ldsyjsqx;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getZlnd() {
        return zlnd;
    }

    public void setZlnd(String zlnd) {
        this.zlnd = zlnd;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }


    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getLdsyqxsfyj() {
        return ldsyqxsfyj;
    }

    public void setLdsyqxsfyj(String ldsyqxsfyj) {
        this.ldsyqxsfyj = ldsyqxsfyj;
    }
}
